@@ -1,5 +1,7 @@
 from hurricane.metrics.registry import MetricsRegistry
 from hurricane.metrics.requests import (
+    HealthMetric,
+    ReadinessMetric,
     RequestCounterMetric,
     RequestQueueLengthMetric,
     ResponseTimeAverageMetric,
@@ -12,3 +14,5 @@ registry.register(RequestCounterMetric)
 registry.register(RequestQueueLengthMetric)
 registry.register(ResponseTimeAverageMetric)
 registry.register(StartupTimeMetric)
+registry.register(HealthMetric)
+registry.register(ReadinessMetric)
